@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: board_properties.c,v 1.16 2004/01/20 07:52:28 fuyu Exp $
+ * $Id: board_properties.c,v 1.16.2.1 2004/05/01 04:34:27 fuyu Exp $
  */
 
 #include "config.h"
@@ -492,6 +492,8 @@ board_properties_response_cb(GtkWidget *dialog, int response_id,
 	states->info->properties_dialog = NULL;
       }
       BOARD_PROPERTIES_UNLOCK;
+      gtk_widget_hide(dialog);
+      gtk_widget_unrealize(dialog);
       gtk_widget_destroy(dialog);
     }
 }
