@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.92.2.2 2004/05/04 09:16:20 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.92.2.3 2004/05/15 15:41:22 fuyu Exp $
  */
 
 #include "config.h"
@@ -2028,7 +2028,9 @@ process_board_move(OchushaBulletinBoard *old_board,
   fprintf(stderr, "process_board_move: old_board=%p new_board=%p\n",
 	  old_board, new_board);
 #endif
-  return new_board;	/* ǤϿΤͥ */
+  ochusha_bulletin_board_set_base_url(old_board,
+			ochusha_bulletin_board_get_base_url(new_board));
+  return old_board;
 }
 
 
