@@ -23,12 +23,20 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui_private.h,v 1.10 2004/01/23 18:50:38 fuyu Exp $
+ * $Id: ochusha_ui_private.h,v 1.11.2.1 2004/05/15 17:04:56 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_PRIVATE_H_
 #define _OCHUSHA_UI_PRIVATE_H_
 
+#ifdef USE_GTK22_API
+/* ʡad-hocн */
+#undef GTK_DISABLE_DEPRECATED
+#include <gtk/gtk.h>
+#undef GTK_MINOR_VERSION
+#define GTK_MINOR_VERSION 2
+#endif
+
 #include <pthread.h>
 
 #ifdef __cplusplus
@@ -103,7 +111,8 @@ void ochu_threads_leave(void);
   do									\
     {									\
       pthread_t self = pthread_self();					\
-      if (last_lock_owner != NULL || self != main_thread)		\
+      if (main_thread != NULL						\
+	  && (last_lock_owner != NULL || self != main_thread))		\
 	{								\
 	  fprintf(stderr,						\
 		  "invalid lock condition at %s, line %d: main=%p, prev=%p self=%p\n", \
