@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.h,v 1.34 2004/01/15 02:18:05 fuyu Exp $
+ * $Id: threadlist_view.h,v 1.36 2004/02/05 01:05:46 fuyu Exp $
  */
 
 #ifndef _THREADLIST_VIEW_H_
@@ -263,6 +263,9 @@ void threadlist_view_initialize_default_view(ThreadlistView *view);
 
 gboolean threadlist_view_open(ThreadlistView *view);
 void threadlist_view_close(ThreadlistView *view);
+void threadlist_view_show(ThreadlistView *view);
+void threadlist_view_freeze(ThreadlistView *view);
+void threadlist_view_chew(ThreadlistView *view);
 void threadlist_view_append_thread(ThreadlistView *view,
 				   OchushaBBSThread *thread,
 				   int num_shown, int num_unread,
