@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha.h,v 1.16 2004/01/30 22:55:47 fuyu Exp $
+ * $Id: ochusha.h,v 1.17.2.2 2004/05/15 16:32:11 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_H_
@@ -54,7 +54,6 @@ extern "C" {
 #define OCHUSHA_SUBJECT_TXT		"subject.txt"
 #define OCHUSHA_SUBBACK_HTML		"subback.html"
 
-#define OCHUSHA_DOLIB_HOST		"tiger2.he.net"
 #define OCHUSHA_DOLIB_URL		"https://tiger2.he.net/~tora3n2c/futen.cgi"
 #define OCHUSHA_DOLIB_USER_AGENT	"DOLIB/1.00"
 #define OCHUSHA_DOLIB_X_2CH_UA		"Ochusha/" VERSION
@@ -84,6 +83,8 @@ struct _OchushaConfig
 
   /* İμѤURL: 2ch¸ʤΤ;ɤ٤⤷ */
   char *bbsmenu_url;
+
+  char *login_2ch_url;
   gboolean login_2ch;
   char *session_id_2ch;
 
@@ -131,12 +132,16 @@ int ochusha_config_cache_open_file(const OchushaConfig *config,
 				   const char *url, int flags);
 void ochusha_config_cache_unlink_file(const OchushaConfig *config,
 				      const char *url);
+int ochusha_config_image_cache_open_file(const OchushaConfig *config,
+					 const char *url, int flags);
+void ochusha_config_image_cache_unlink_file(const OchushaConfig *config,
+					    const char *url);
 
 
 /*
  * config.xmlϢ
  */
-typedef void WritePreferenceElementFunc(gzFile *config_xml,
+typedef void WritePreferenceElementFunc(gzFile config_xml,
 					gpointer user_data);
 typedef void ReadPreferenceElementFunc(GHashTable *pref_attrs,
 				       gpointer user_data);
