@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_table.c,v 1.26 2004/02/05 00:55:51 fuyu Exp $
+ * $Id: ochusha_bbs_table.c,v 1.27 2004/04/13 15:38:05 fuyu Exp $
  */
 
 #include "config.h"
@@ -1061,7 +1061,7 @@ ochusha_bbs_table_read_boardlist_xml(OchushaBBSTable *table,
 typedef struct _WriteBoardlistArgs
 {
   OchushaBBSTable *table;
-  gzFile *boardlist_xml;
+  gzFile boardlist_xml;
 } WriteBoardlistArgs;
 
 
@@ -1070,7 +1070,7 @@ write_board(gpointer data, gpointer user_data)
 {
   OchushaBulletinBoard *board = OCHUSHA_BULLETIN_BOARD(data);
   WriteBoardlistArgs *args = (WriteBoardlistArgs *)user_data;
-  gzFile *boardlist_xml = args->boardlist_xml;
+  gzFile boardlist_xml = args->boardlist_xml;
 
   if (board->killed)
     return;
@@ -1099,7 +1099,7 @@ write_category(gpointer data, gpointer user_data)
 {
   OchushaBoardCategory *category = OCHUSHA_BOARD_CATEGORY(data);
   WriteBoardlistArgs *args = (WriteBoardlistArgs *)user_data;
-  gzFile *boardlist_xml = args->boardlist_xml;
+  gzFile boardlist_xml = args->boardlist_xml;
 
   if (category->killed)
     return;
@@ -1127,7 +1127,7 @@ ochusha_bbs_table_write_boardlist_xml(OchushaBBSTable *table,
 				      const char *subdir)
 {
   WriteBoardlistArgs args;
-  gzFile *boardlist_xml;
+  gzFile boardlist_xml;
   int fd;
 
   g_return_val_if_fail(OCHUSHA_IS_BBS_TABLE(table) && config != NULL, FALSE);
