@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.h,v 1.24 2004/02/26 06:05:10 fuyu Exp $
+ * $Id: ochusha_bbs_thread.h,v 1.25 2004/04/13 15:38:05 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BBS_THREAD_H_
@@ -86,7 +86,7 @@ struct _OchushaBBSThreadClass
   void (*read_threadlist_element)(OchushaBBSThread *thread,
 				  GHashTable *thread_attributes);
   void (*write_threadlist_element)(OchushaBBSThread *thread,
-				   gzFile *threadlist_xml);
+				   gzFile threadlist_xml);
 
 
   /* postξܤˤ륷ʥ */
