@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_2ch.c,v 1.42 2004/02/26 06:05:10 fuyu Exp $
+ * $Id: ochusha_board_2ch.c,v 1.45 2004/04/13 15:38:05 fuyu Exp $
  */
 
 #include "config.h"
@@ -64,7 +64,7 @@ static void ochusha_board_2ch_read_boardlist_element(
 						GHashTable *board_attributes);
 static void ochusha_board_2ch_write_boardlist_element(
 						OchushaBulletinBoard *board,
-						gzFile *boardlist_xml);
+						gzFile boardlist_xml);
 
 static const char *ochusha_board_2ch_get_subject_txt_encoding(
 						OchushaBulletinBoard *board);
@@ -75,6 +75,8 @@ static char *ochusha_board_2ch_generate_base_path(OchushaBulletinBoard *board,
 						  const char *url);
 static char *ochusha_board_2ch_generate_board_id(OchushaBulletinBoard *board,
 						 const char *url);
+static void ochusha_board_2ch_server_changed(OchushaBulletinBoard *board,
+					     const char *prev_server);
 static OchushaBBSThread *ochusha_board_2ch_thread_new(
 						OchushaBulletinBoard *board,
 						const char *id,
@@ -164,6 +166,7 @@ ochusha_board_2ch_class_init(OchushaBoard2chClass *klass)
   b_class->recover_threadlist = ochusha_board_2ch_recover_threadlist;
   b_class->generate_base_path = ochusha_board_2ch_generate_base_path;
   b_class->generate_board_id = ochusha_board_2ch_generate_board_id;
+  b_class->server_changed = ochusha_board_2ch_server_changed;
   b_class->thread_new = ochusha_board_2ch_thread_new;
   b_class->lookup_thread_by_url = ochusha_board_2ch_lookup_thread_by_url;
   b_class->lookup_kako_thread_by_url
@@ -233,16 +236,50 @@ ochusha_board_2ch_finalize(GObject *object)
 }
 
 
+static void
+add_a_server(OchushaBoard2ch *board_2ch, const char *server)
+{
+  g_return_if_fail(server != NULL);
+  g_return_if_fail(strlen(server) > 0);
+
+  if (g_slist_find_custom(board_2ch->server_history, server,
+			  (GCompareFunc)strcmp) == NULL)
+    board_2ch->server_history = g_slist_prepend(board_2ch->server_history,
+						G_STRDUP(server));
+}
+
+
 static void
 ochusha_board_2ch_read_boardlist_element(OchushaBulletinBoard *board,
 					 GHashTable *board_attributes)
 {
   OchushaBoard2ch *board_2ch = OCHUSHA_BOARD_2CH(board);
+  char *servers;
+
   board_2ch->last_modified
     = ochusha_utils_get_attribute_string(board_attributes, "last_modified");
   board_2ch->cookie
     = ochusha_utils_get_attribute_string(board_attributes, "cookie");
 
+  servers = ochusha_utils_get_attribute_string(board_attributes,
+					       "server_history");
+  if (servers != NULL)
+    {
+      char *cur_pos = servers;
+      while (TRUE)
+	{
+	  char *tmp_pos = strchr(cur_pos, ',');
+	  if (tmp_pos != NULL)
+	    *tmp_pos = '\0';
+	  add_a_server(board_2ch, cur_pos);
+	  if (tmp_pos == NULL)
+	    break;
+	  cur_pos = tmp_pos + 1;
+	}
+
+      G_FREE(servers);
+    }
+
   if (parent_class->read_boardlist_element != NULL)
     (*parent_class->read_boardlist_element)(board, board_attributes);
 }
@@ -263,15 +300,42 @@ ochusha_board_2ch_read_boardlist_element(OchushaBulletinBoard *board,
     } while (0)
 
 
+static void
+concat_server_name(const char *server, char **prev_result_p)
+{
+  char *result;
+  if (*prev_result_p == NULL)
+    result = G_STRDUP(server);
+  else
+    {
+      result = g_strconcat(*prev_result_p, ",", server, NULL);
+      G_FREE(*prev_result_p);
+    }
+  *prev_result_p = result;
+}
+
+
 static void
 ochusha_board_2ch_write_boardlist_element(OchushaBulletinBoard *board,
-					  gzFile *boardlist_xml)
+					  gzFile boardlist_xml)
 {
   OchushaBoard2ch *board_2ch = OCHUSHA_BOARD_2CH(board);
 
   if (parent_class->write_boardlist_element != NULL)
     (*parent_class->write_boardlist_element)(board, boardlist_xml);
 
+  if (board_2ch->server_history != NULL)
+    {
+      char *servers = NULL;
+      g_slist_foreach(board_2ch->server_history, (GFunc)concat_server_name,
+		      &servers);
+      gzprintf(boardlist_xml,
+	       "        <attribute name=\"server_history\">\n"
+	       "          <string>%s</string>\n"
+	       "        </attribute>\n", servers);
+      G_FREE(servers);
+    }
+
   OUTPUT_BOARD_ATTRIBUTE_STRING(boardlist_xml, board_2ch, last_modified);
   OUTPUT_BOARD_ATTRIBUTE_STRING(boardlist_xml, board_2ch, cookie);
 }
@@ -452,6 +516,22 @@ ochusha_board_2ch_generate_board_id(OchushaBulletinBoard *board,
 }
 
 
+static void
+ochusha_board_2ch_server_changed(OchushaBulletinBoard *board,
+				 const char *prev_server)
+{
+  OchushaBoard2ch *board_2ch;
+  g_return_if_fail(OCHUSHA_IS_BOARD_2CH(board) && prev_server != NULL);
+
+  board_2ch = OCHUSHA_BOARD_2CH(board);
+  /* XXX server_historyϿ롣
+   *     boardlist.xmlؤν񤭹߻˥ꥹȤ񤭽Ф
+   *     xmlǤϤɤäʡġġ
+   */
+  add_a_server(board_2ch, prev_server);
+}
+
+
 static OchushaBBSThread *
 ochusha_board_2ch_thread_new(OchushaBulletinBoard *board, const char *id,
 			     const gchar *title)
@@ -506,7 +586,7 @@ ochusha_board_2ch_lookup_thread_by_url(OchushaBulletinBoard *board,
   if (thread_id != NULL)
     G_FREE(thread_id);
 
-#if 1
+#if 0
   if (thread == NULL)
     fprintf(stderr, "ochusha_board_2ch_lookup_thread_by_url: %s\n", url);
 #endif
@@ -917,11 +997,11 @@ collect_dropped_thread(gpointer data, gpointer user_data)
     {
       /* threadDATäݤ*/
       OchushaBBSThread *thread = (OchushaBBSThread *)thread_2ch;
+      thread->flags |= OCHUSHA_BBS_THREAD_DAT_DROPPED;
       if (thread->number_of_responses_read > 0)
 	{
 	  if (g_slist_find(args->thread_list, thread) == NULL)
 	    {
-	      thread->flags |= OCHUSHA_BBS_THREAD_DAT_DROPPED;
 	      thread->number_of_responses_on_server = 0;
 	      args->thread_list = g_slist_append(args->thread_list, thread);
 	      if (args->each_thread_cb != NULL)
