@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_jbbs.c,v 1.15 2004/01/27 11:58:11 fuyu Exp $
+ * $Id: ochusha_board_jbbs.c,v 1.17 2004/02/05 01:04:55 fuyu Exp $
  */
 
 #include "config.h"
@@ -53,7 +53,7 @@
 #include <unistd.h>
 
 
-#define ANALYSIS_INTERVAL	50
+#define ANALYSIS_INTERVAL	200
 
 
 static void ochusha_board_jbbs_class_init(OchushaBoardJBBSClass *klass);
@@ -100,7 +100,8 @@ static gboolean ochusha_board_jbbs_create_new_thread(
 					OchushaBulletinBoard *board,
 					OchushaNetworkBroker *broker,
 					const gchar *title,
-					const OchushaBBSResponse *response);
+					const OchushaBBSResponse *response,
+					gboolean use_id);
 
 
 GType
@@ -420,7 +421,8 @@ static gboolean
 ochusha_board_jbbs_create_new_thread(OchushaBulletinBoard *board,
 				     OchushaNetworkBroker *broker,
 				     const gchar *title_utf8,
-				     const OchushaBBSResponse *response)
+				     const OchushaBBSResponse *response,
+				     gboolean use_id)
 {
 #if 0	/* Ǥ̤ݡ */
   OchushaBoard2ch *board_2ch;
@@ -606,11 +608,7 @@ ochusha_board_jbbs_get_threadlist_source(OchushaBulletinBoard *board,
       if (snprintf(url, PATH_MAX, "%s" OCHUSHA_SUBBACK_HTML, board->base_url)
 	  >= PATH_MAX)
 	return NULL;
-#if 1	/* ʤǤΤasync⡼ɤǥȼԤ롣*/
-      return ochusha_network_broker_read_from_cgi(broker, buffer, url);
-#else
       break;
-#endif
 
     case OCHUSHA_BBS_TYPE_JBBS:
     case OCHUSHA_BBS_TYPE_MACHIBBS:
