@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_config.c,v 1.28.2.1 2004/05/01 16:02:58 fuyu Exp $
+ * $Id: ochusha_config.c,v 1.28.2.2 2004/05/15 16:32:11 fuyu Exp $
  */
 
 #include "config.h"
@@ -1068,6 +1068,8 @@ ochusha_write_config_xml(OchushaConfig *config, const char *subdir,
   gzprintf(config_xml, "  <preference>\n");
 
   OUTPUT_CONFIG_ATTRIBUTE_STRING(config_xml, config, bbsmenu_url);
+  OUTPUT_CONFIG_ATTRIBUTE_STRING(config_xml, config, login_2ch_url);
+
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(config_xml, config, offline);
 
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(config_xml, config, enable_proxy);
@@ -1125,6 +1127,7 @@ ochusha_read_config_xml(OchushaConfig *config, const char *subdir,
   if (pathname == NULL)
     {
       config->bbsmenu_url = G_STRDUP(OCHUSHA_DEFAULT_BBSMENU_URL);
+      config->login_2ch_url = G_STRDUP(OCHUSHA_DOLIB_URL);
       config->offline = FALSE;
 
       config->enable_proxy = FALSE;
@@ -1167,6 +1170,11 @@ ochusha_read_config_xml(OchushaConfig *config, const char *subdir,
 
       config->bbsmenu_url
 	= ochusha_utils_get_attribute_string(pref, "bbsmenu_url");
+      config->login_2ch_url
+	= ochusha_utils_get_attribute_string(pref, "login_2ch_url");
+      if (config->login_2ch_url == NULL)
+	config->login_2ch_url = G_STRDUP(OCHUSHA_DOLIB_URL);
+
       config->offline = ochusha_utils_get_attribute_boolean(pref, "offline");
 
       config->enable_proxy
