@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.40 2004/02/20 09:12:48 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.40.2.1 2004/05/15 16:32:11 fuyu Exp $
  */
 
 #include "config.h"
@@ -1226,6 +1226,7 @@ ochusha_utils_2ch_login(OchushaConfig *config, OchushaNetworkBroker *broker,
   OchushaNetworkBrokerPostStatus post_status;
   char *session_id = NULL;
   gboolean post_result;
+  char *server;
 
   config->login_2ch = FALSE;
   if (config->session_id_2ch != NULL)
@@ -1237,13 +1238,21 @@ ochusha_utils_2ch_login(OchushaConfig *config, OchushaNetworkBroker *broker,
   g_return_if_fail(OCHUSHA_IS_NETWORK_BROKER(broker));
   g_return_if_fail(user_id != NULL && passwd != NULL);
 
+  if (config->login_2ch_url == NULL)
+    config->login_2ch_url = G_STRDUP(OCHUSHA_DOLIB_URL);
+
+  server = ochusha_utils_url_extract_http_server(config->login_2ch_url);
+  g_return_if_fail(server != NULL);
+
   snprintf(content_body, 4096, "ID=%s&PW=%s", user_id, passwd);
   post_result = ochusha_network_broker_try_post_raw(broker,
-						    OCHUSHA_DOLIB_URL,
-						    OCHUSHA_DOLIB_HOST,
+						    config->login_2ch_url,
+						    server,
 						    headers, content_body,
 						    &post_status);
 
+  G_FREE(server);
+
   if (post_result)
     {
 #if DEBUG_LOGIN
