@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: utils.c,v 1.30 2004/04/13 15:36:12 fuyu Exp $
+ * $Id: utils.c,v 1.30.2.2 2004/05/15 16:32:11 fuyu Exp $
  */
 
 #define OCHUSHA_UTILS_IMPLEMENTATION	1
@@ -288,19 +288,26 @@ ochusha_utils_url_extract_http_server(const char *url)
   /*
    * ݤʤΤǡurlhttp://server/.*ʷǤȷǤġ
    */
-  char *cur_pos = strstr(url, "http://");
+  char *cur_pos;
   char *hostpart_tail;
   int length;
   char buffer[MAX_HOSTNAME_LEN];
 
+  cur_pos = strstr(url, "http://");
   if (cur_pos == NULL)
     {
+      cur_pos = strstr(url, "https://");
+      if (cur_pos == NULL)
+	{
 #if DEBUG_UTILS
-      fprintf(stderr, "Not a http URL: %s\n", url);
+	  fprintf(stderr, "Not a http URL: %s\n", url);
 #endif
-      return NULL;
+	  return NULL;
+	}
+      cur_pos += 8;	/* skip "https://" */
     }
-  cur_pos += 7;	/* skip "http://" */
+  else
+    cur_pos += 7;	/* skip "http://" */
 
   hostpart_tail = strchr(cur_pos, '/');
   if (hostpart_tail == NULL)
@@ -583,7 +590,6 @@ int
 parse_int(const gchar *start, size_t len)
 {
   int result = 0;
-#if 1
   const gchar *tmp_pos = start;
   const gchar *tail_pos = (len > 0 ? start + len : NULL);
   gunichar c;
@@ -601,20 +607,6 @@ parse_int(const gchar *start, size_t len)
     } while (tmp_pos != NULL);
 
   return result;
-#else
-  char tmp_buffer[128];
-
-  if (len > 0)
-    {
-      len = MIN(127, len);
-      memcpy(tmp_buffer, start, len);
-      tmp_buffer[len] = '\0';
-    }
-  else
-    g_strlcpy(tmp_buffer, start, 128);
-  sscanf(tmp_buffer, "%d", &result);
-  return result;
-#endif
 }
 
 
