@@ -1,17 +1,17 @@
 /**********************************************************************
 
-  iso8859_9.c -  Oniguruma (regular expression library)
+  iso8859_5.c -  Oniguruma (regular expression library)
 
   Copyright (C) 2004  K.Kosako (kosako@sofnec.co.jp)
 
 **********************************************************************/
 #include "regenc.h"
 
-#define ENC_ISO_8859_9_TO_LOWER_CASE(c) EncISO_8859_9_ToLowerCaseTable[c]
-#define ENC_IS_ISO_8859_9_CTYPE(code,ctype) \
-  ((EncISO_8859_9_CtypeTable[code] & ctype) != 0)
+#define ENC_ISO_8859_5_TO_LOWER_CASE(c) EncISO_8859_5_ToLowerCaseTable[c]
+#define ENC_IS_ISO_8859_5_CTYPE(code,ctype) \
+  ((EncISO_8859_5_CtypeTable[code] & ctype) != 0)
 
-static UChar EncISO_8859_9_ToLowerCaseTable[256] = {
+static UChar EncISO_8859_5_ToLowerCaseTable[256] = {
   '\000', '\001', '\002', '\003', '\004', '\005', '\006', '\007',
   '\010', '\011', '\012', '\013', '\014', '\015', '\016', '\017',
   '\020', '\021', '\022', '\023', '\024', '\025', '\026', '\027',
@@ -32,21 +32,21 @@ static UChar EncISO_8859_9_ToLowerCaseTable[256] = {
   '\210', '\211', '\212', '\213', '\214', '\215', '\216', '\217',
   '\220', '\221', '\222', '\223', '\224', '\225', '\226', '\227',
   '\230', '\231', '\232', '\233', '\234', '\235', '\236', '\237',
-  '\240', '\241', '\242', '\243', '\244', '\245', '\246', '\247',
-  '\250', '\251', '\252', '\253', '\254', '\255', '\256', '\257',
-  '\260', '\261', '\262', '\263', '\264', '\265', '\266', '\267',
-  '\270', '\271', '\272', '\273', '\274', '\275', '\276', '\277',
+  '\240', '\361', '\362', '\363', '\364', '\365', '\366', '\367',
+  '\370', '\371', '\372', '\373', '\374', '\255', '\376', '\377',
+  '\320', '\321', '\322', '\323', '\324', '\325', '\326', '\327',
+  '\330', '\331', '\332', '\333', '\334', '\335', '\336', '\337',
   '\340', '\341', '\342', '\343', '\344', '\345', '\346', '\347',
   '\350', '\351', '\352', '\353', '\354', '\355', '\356', '\357',
-  '\360', '\361', '\362', '\363', '\364', '\365', '\366', '\327',
-  '\370', '\371', '\372', '\373', '\374', '\335', '\376', '\337',
+  '\320', '\321', '\322', '\323', '\324', '\325', '\326', '\327',
+  '\330', '\331', '\332', '\333', '\334', '\335', '\336', '\337',
   '\340', '\341', '\342', '\343', '\344', '\345', '\346', '\347',
   '\350', '\351', '\352', '\353', '\354', '\355', '\356', '\357',
   '\360', '\361', '\362', '\363', '\364', '\365', '\366', '\367',
   '\370', '\371', '\372', '\373', '\374', '\375', '\376', '\377'
 };
 
-static unsigned short EncISO_8859_9_CtypeTable[256] = {
+static unsigned short EncISO_8859_5_CtypeTable[256] = {
   0x1004, 0x1004, 0x1004, 0x1004, 0x1004, 0x1004, 0x1004, 0x1004,
   0x1004, 0x1106, 0x1104, 0x1104, 0x1104, 0x1104, 0x1004, 0x1004,
   0x1004, 0x1004, 0x1004, 0x1004, 0x1004, 0x1004, 0x1004, 0x1004,
@@ -67,54 +67,46 @@ static unsigned short EncISO_8859_9_CtypeTable[256] = {
   0x0004, 0x0004, 0x0004, 0x0004, 0x0004, 0x0004, 0x0004, 0x0004,
   0x0004, 0x0004, 0x0004, 0x0004, 0x0004, 0x0004, 0x0004, 0x0004,
   0x0004, 0x0004, 0x0004, 0x0004, 0x0004, 0x0004, 0x0004, 0x0004,
-  0x0142, 0x00d0, 0x0050, 0x0050, 0x0050, 0x0050, 0x0050, 0x0050,
-  0x0050, 0x0050, 0x0871, 0x00d0, 0x0050, 0x00d0, 0x0050, 0x0050,
-  0x0050, 0x0050, 0x0850, 0x0850, 0x0050, 0x0871, 0x0050, 0x00d0,
-  0x0050, 0x0850, 0x0871, 0x00d0, 0x0850, 0x0850, 0x0850, 0x00d0,
+  0x0142, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51,
+  0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x00d0, 0x0a51, 0x0a51,
+  0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51,
+  0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51,
   0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51,
   0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51,
-  0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0050,
-  0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0a51, 0x0871,
   0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871,
   0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871,
-  0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0050,
-  0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871
+  0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871,
+  0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871,
+  0x0050, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0871,
+  0x0871, 0x0871, 0x0871, 0x0871, 0x0871, 0x0050, 0x0871, 0x0871
 };
 
 static int
-iso_8859_9_mbc_to_lower(UChar* p, UChar* lower)
+iso_8859_5_mbc_to_lower(UChar* p, UChar* lower)
 {
-  *lower = ENC_ISO_8859_9_TO_LOWER_CASE(*p);
+  *lower = ENC_ISO_8859_5_TO_LOWER_CASE(*p);
   return 1; /* return byte length of converted char to lower */
 }
 
 static int
-iso_8859_9_mbc_is_case_ambig(UChar* p)
+iso_8859_5_mbc_is_case_ambig(UChar* p)
 {
-  int v = (EncISO_8859_9_CtypeTable[*p] &
+  int v = (EncISO_8859_5_CtypeTable[*p] &
 	   (ONIGENC_CTYPE_UPPER | ONIGENC_CTYPE_LOWER));
 
-  if ((v | ONIGENC_CTYPE_LOWER) != 0) {
-    /* 0xdf, 0xaa, 0xb5, 0xba are lower case letter, but can't convert. */
-    if (*p == 0xdf || (*p >= 0xaa && *p <= 0xba))
-      return FALSE;
-    else
-      return TRUE;
-  }
-
   return (v != 0 ? TRUE : FALSE);
 }
 
 static int
-iso_8859_9_code_is_ctype(OnigCodePoint code, unsigned int ctype)
+iso_8859_5_code_is_ctype(OnigCodePoint code, unsigned int ctype)
 {
   if (code < 256)
-    return ENC_IS_ISO_8859_9_CTYPE(code, ctype);
+    return ENC_IS_ISO_8859_5_CTYPE(code, ctype);
   else
     return FALSE;
 }
 
-OnigEncodingType OnigEncodingISO_8859_9 = {
+OnigEncodingType OnigEncodingISO_8859_5 = {
   {
     1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
     1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
@@ -133,20 +125,20 @@ OnigEncodingType OnigEncodingISO_8859_9 = {
     1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
     1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1
   },
-  "ISO-8859-9",  /* name */
+  "ISO-8859-5",  /* name */
   1,             /* max byte length */
-  TRUE,          /* is_fold_match */
+  FALSE,         /* is_fold_match */
   ONIGENC_CTYPE_SUPPORT_LEVEL_SB,    /* ctype_support_level */
   TRUE,          /* is continuous sb mb codepoint */
   onigenc_single_byte_mbc_to_code,
   onigenc_single_byte_code_to_mbclen,
   onigenc_single_byte_code_to_mbc,
-  iso_8859_9_mbc_to_lower,
-  iso_8859_9_mbc_is_case_ambig,
-  iso_8859_9_code_is_ctype,
+  iso_8859_5_mbc_to_lower,
+  iso_8859_5_mbc_is_case_ambig,
+  iso_8859_5_code_is_ctype,
   onigenc_nothing_get_ctype_code_range,
   onigenc_single_byte_left_adjust_char_head,
   onigenc_single_byte_is_allowed_reverse_match,
-  onigenc_get_all_fold_match_code_ss_0xdf,
-  onigenc_get_fold_match_info_ss_0xdf
+  onigenc_nothing_get_all_fold_match_code,
+  onigenc_nothing_get_fold_match_info
 };
